<template>
  <div>
    <el-dialog :visible.sync="addTrainingPlanDia" title="新增培训计划" width="50%">
      <div class="body">
        <el-form ref="trainingPlan" :model="trainingPlan" label-position="right" label-width="90px" :rules="trainingPlanRules">
          <el-row>
            <el-col :span="12">
              <el-form-item label="培训日期:" prop="trainingDate">
                <el-date-picker v-model="trainingPlan.trainingDate" format="yyyy-MM-dd"
                                placeholder="选择日期" size="small" value-format="yyyy-MM-dd"
                                type="date" style="width: 100%"></el-date-picker>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="课时:">
                <el-input type="number" v-model="trainingPlan.classHour" label="描述文字" size="small"></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="开始时间:" prop="openingTime">
                <el-time-picker v-model="trainingPlan.openingTime" placeholder="选择时间"
                                size="small" style="width: 100%" value-format="HH:mm:ss"></el-time-picker>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="结束时间:" prop="endTime">
                <el-time-picker v-model="trainingPlan.endTime" placeholder="选择时间" size="small"
                                style="width: 100%" value-format="HH:mm:ss"></el-time-picker>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="培训目标:">
                <el-input v-model="trainingPlan.trainingObjectives" placeholder="请输入" size="small"></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="参加对象:">
                <el-input v-model="trainingPlan.participants" placeholder="请输入" size="small"></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="培训内容:" prop="trainingContent">
                <el-input v-model="trainingPlan.trainingContent" placeholder="请输入" size="small"></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="培训讲师:" prop="trainingLecturerId">
                <el-select v-model="trainingPlan.trainingLecturerId"
                           clearable filterable
                           placeholder="请选择" size="small" style="width: 100%;">
                  <el-option v-for="item in responsibleOptions" :key="item.id" :label="item.name" :value="item.id">
                  </el-option>
                </el-select>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="课题学分:">
                <el-input type="number" v-model="trainingPlan.projectCredits" label="描述文字" size="small"></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="培训地点:">
                <el-input v-model="trainingPlan.placeTraining" placeholder="请输入" size="small"></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="培训方式:">
                <el-input v-model="trainingPlan.trainingMode" placeholder="请输入" size="small"></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="举办部门:">
                <el-input v-model="trainingPlan.holdingDepartment" placeholder="请输入" size="small"></el-input>
              </el-form-item>
            </el-col>
          </el-row>
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
				<el-button @click="closeAdd">取 消</el-button>
        <el-button type="primary" @click="submitAdd">确 定</el-button>
			</span>
    </el-dialog>
  </div>
</template>

<script>
export default {
  props: {
    currentChangeRow: {
      type: Object,
      default: () => {
        return {}
      }
    },
  },
  name: 'Add',
  // import 引入的组件需要注入到对象中才能使用
  components: {},
  data() {
    // 这里存放数据
    return {
      addTrainingPlanDia: false,
      trainingPlan: {
        planId: '',
      },
      trainingPlanRules: {
        trainingDate: [{ required: true, message: '请选择培训日期', trigger: 'change' }],
        openingTime: [{ required: true, message: '请选择开始时间', trigger: 'change' }],
        endTime: [{ required: true, message: '请选择结束时间', trigger: 'change' }],
        trainingContent: [{ required: true, message: '请输入培训内容', trigger: 'change' }],
        trainingLecturerId: [{ required: true, message: '请选择培训讲师', trigger: 'change' }],
      },
      responsibleOptions: [],
    };
  },
  // 方法集合
  methods: {
    showDialog(id) {
      this.addTrainingPlanDia = true;
      this.trainingPlan.planId = id
      this.getUserList()
    },
    // 提交新增
    submitAdd() {
      this.$refs.trainingPlan.validate((valid) => {
        if (valid) {
          this.trainingPlan.planId = this.currentChangeRow.id
          const personTrainingDetailed = this.trainingPlan
          this.$axios.post(this.$api.personnel.addOrUpdatePersonTrainingDetailed, personTrainingDetailed, {
            headers: {
              'Content-Type': 'application/json'
            },
            noQs: true
          }).then(res => {
            if (res.code == 200) {
              this.$message.success('提交成功');
              this.closeAdd();
              this.dialogVisible = false;
            }
          });
        }
      })
    },
    // 关闭弹框
    closeAdd() {
      this.$refs.trainingPlan.resetFields();
      this.$emit('search')
      this.addTrainingPlanDia = false;
    },
    // 获取负责人信息接口
    getUserList() {
      this.$axios.get(this.$api.deviceScope.selectUserList).then(res => {
        if (res.code == 200) {
          this.responsibleOptions = res.data;
        }
      });
    },
  },
  watch: {
    addTrainingPlanDia(newVal) {
      if (newVal) {
        this.trainingPlan = {
          planId: '',
        }
      }
    }
  }
};
</script>

<style scoped>
</style>
